 /*
 * file      : build.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <glib/gstdio.h>

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <stdlib.h>
#include <pthread.h>

#include "../libbasebuild/libbasebuild.h"
#include "global.h"
#include "configuser.h"
#include "callbacks.h"
#include "build.h"
#include "view.h"
#include "win_result.h"
#include "win_info.h"


VAR_BUILD VarBuild = {	// BUFFERS
	NULL,		// GstrMakefileAm
	NULL,		// GstrConfigureIn
	NULL,		// GstrSrcMakefileAm
	NULL,		// GstrSrc2MakefileAm
	NULL,		// GstrManMakefileAm
	NULL,		// GstrLibMakefileAm
	NULL,		// GstrPixmapsMakefileAm
	NULL,		// GstrMenuMakefileAm
	NULL,		// GstrMimeMakefileAm
	NULL		// GstrGladeMakefileAm
};

typedef struct {
	
	gchar		*PathProject;			// Path du projet
	gchar		*NameProject;			// Nom du projet
	gchar		*VersionProject;		// Version du projet
	gchar		*NewPathName;			// Path + Nom + Version du projet
	gchar		*PathNameLib;			// Path dossier Lib
	gchar		*PathNameSrc;			// Path dossier Src
	gchar		*PathNameSrc2;			// Path dossier Src2
	gchar		*PathNameMan;			// Path dossier Man
	gchar		*PathNamePo;			// Path dossier Po
	gchar		*PathNamePixmaps;		// Path dossier Pixmaps
	gchar		*PathNameMenu;			// Path dossier Menu
	gchar		*PathNameMime;			// Path dossier Mime
	gchar		*PathNameGlade;			// Path dossier Glade
	
	gboolean	Bool_lib_gtk;			// checkbutton_lib_gtk		-> glade/ + gtk+-2.0 + glib-2.0
	gboolean	Bool_lib_gthread;		// checkbutton_lib_gthread	-> gthread-2.0 + pthread

	gboolean	Bool_dossier_src2;		// checkbutton_dossier_src2
	gboolean	Bool_dossier_po;		// checkbutton_dossier_po
	gboolean	Bool_dossier_manpage;		// checkbutton_dossier_manpage
	gboolean	Bool_dossier_lib_statique;	// checkbutton_dossier_lib_statique
	gboolean	Bool_dossier_pixmaps;		// checkbutton_dossier_pixmaps
	gboolean	Bool_dossier_menu;		// checkbutton_dossier_menu
	gboolean	Bool_dossier_mime;		// checkbutton_dossier_mime
	gboolean	Bool_dossier_glade;		// checkbutton_dossier_glade
	
	gboolean	Bool_package_name_is_glade;	// 
	
} VAR_OPTIONS;

VAR_OPTIONS VarOptions;



// --------------------------------------------------------------------------
// 
// GENERATION EN MEMOIRE
// 
// --------------------------------------------------------------------------

// FREE ALLOCATIONS
// 
void build_remove_options (void)
{
	if (NULL != VarOptions.PathProject) {
		g_free (VarOptions.PathProject);
		VarOptions.PathProject = NULL;
	}
	if (NULL != VarOptions.NameProject) {
		g_free (VarOptions.NameProject);
		VarOptions.NameProject = NULL;
	}
	if (NULL != VarOptions.VersionProject) {
		g_free (VarOptions.VersionProject);
		VarOptions.VersionProject = NULL;
	}
	if (NULL != VarOptions.NewPathName) {
		g_free (VarOptions.NewPathName);
		VarOptions.NewPathName = NULL;
	}
	if (NULL != VarOptions.PathNameLib) {
		g_free (VarOptions.PathNameLib);
		VarOptions.PathNameLib = NULL;
	}
	if (NULL != VarOptions.PathNameSrc) {
		g_free (VarOptions.PathNameSrc);
		VarOptions.PathNameSrc = NULL;
	}
	if (NULL != VarOptions.PathNameSrc2) {
		g_free (VarOptions.PathNameSrc2);
		VarOptions.PathNameSrc2 = NULL;
	}
	if (NULL != VarOptions.PathNameMan) {
		g_free (VarOptions.PathNameMan);
		VarOptions.PathNameMan = NULL;
	}
	if (NULL != VarOptions.PathNamePo) {
		g_free (VarOptions.PathNamePo);
		VarOptions.PathNamePo = NULL;
	}
	if (NULL != VarOptions.PathNamePixmaps) {
		g_free (VarOptions.PathNamePixmaps);
		VarOptions.PathNamePixmaps = NULL;
	}
	if (NULL != VarOptions.PathNameMenu) {
		g_free (VarOptions.PathNameMenu);
		VarOptions.PathNameMenu = NULL;
	}
	if (NULL != VarOptions.PathNameMime) {
		g_free (VarOptions.PathNameMime);
		VarOptions.PathNameMime = NULL;
	}
	if (NULL != VarOptions.PathNameGlade) {
		g_free (VarOptions.PathNameGlade);
		VarOptions.PathNameGlade = NULL;
	}
}
// ALLOCATIONS OPTIONS
// 
void build_maj_options (void)
{
	// FREE ALLOCATIONS
	build_remove_options ();
	
	VarOptions.PathProject     = g_strdup (gtk_button_get_label (GTK_BUTTON (VarCallbacks.Adr_button_path)));
	VarOptions.NameProject     = g_strdup (gtk_entry_get_text (GTK_ENTRY (VarCallbacks.Adr_name_project)));
	VarOptions.VersionProject  = g_strdup_printf ("%d.%d.%d",
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_version_A)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_version_B)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_version_C))
					);
	VarOptions.NewPathName     = g_strdup_printf ("%s/%s-%s", VarOptions.PathProject, VarOptions.NameProject, VarOptions.VersionProject);
	VarOptions.PathNameLib     = g_strdup_printf ("%s/lib", VarOptions.NewPathName);
	VarOptions.PathNameSrc     = g_strdup_printf ("%s/src", VarOptions.NewPathName);
	VarOptions.PathNameSrc2    = g_strdup_printf ("%s/src2", VarOptions.NewPathName);
	VarOptions.PathNameMan     = g_strdup_printf ("%s/man", VarOptions.NewPathName);
	VarOptions.PathNamePo      = g_strdup_printf ("%s/po", VarOptions.NewPathName);
	VarOptions.PathNamePixmaps = g_strdup_printf ("%s/pixmaps", VarOptions.NewPathName);
	VarOptions.PathNameMenu    = g_strdup_printf ("%s/menu", VarOptions.NewPathName);
	VarOptions.PathNameMime    = g_strdup_printf ("%s/mime", VarOptions.NewPathName);
	VarOptions.PathNameGlade   = g_strdup_printf ("%s/glade", VarOptions.NewPathName);
	// gtk+-2.0
	// glib-2.0
	// glade/
	VarOptions.Bool_lib_gtk			= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_lib_gtk")));
	// gthread-2.0
	// pthread
	VarOptions.Bool_lib_gthread		= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_lib_gthread")));
	VarOptions.Bool_dossier_src2		= gtk_spin_button_get_value_as_int( GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_label_src)) == 2 ? TRUE : FALSE;
	VarOptions.Bool_dossier_po		= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_po")));
	VarOptions.Bool_dossier_manpage		= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_manpage")));
	VarOptions.Bool_dossier_lib_statique	= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_lib_statique")));
	VarOptions.Bool_dossier_pixmaps		= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_pixmaps")));
	VarOptions.Bool_dossier_menu		= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_menu")));
	VarOptions.Bool_dossier_mime		= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_mime")));
	VarOptions.Bool_dossier_glade		= VarOptions.Bool_lib_gtk;
	
	VarOptions.Bool_package_name_is_glade	= gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("radiobutton_paquet_glade")));
}

// CONSTRUCTION Makefile.am
// 
void build_file_MakefileAm (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrMakefileAm != NULL) {
		g_string_free (VarBuild.GstrMakefileAm, TRUE);
		VarBuild.GstrMakefileAm = NULL;
	}
	VarBuild.GstrMakefileAm = g_string_new (NULL);

	g_string_append_printf (VarBuild.GstrMakefileAm, "#\n# Makefile.am\n#\n");
	g_string_append_printf (VarBuild.GstrMakefileAm, "SUBDIRS = ");
	if (TRUE == VarOptions.Bool_dossier_po) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "po ");
	}
	if (TRUE == VarOptions.Bool_dossier_lib_statique) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "lib ");
	}
	g_string_append_printf (VarBuild.GstrMakefileAm, "src ");
	if (TRUE == VarOptions.Bool_dossier_src2) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "src2 ");
	}
	if (TRUE == VarOptions.Bool_dossier_manpage) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "man ");
	}
	if (TRUE == VarOptions.Bool_dossier_pixmaps) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "pixmaps ");
	}
	if (TRUE == VarOptions.Bool_dossier_menu) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "menu ");
	}
	if (TRUE == VarOptions.Bool_dossier_mime) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "mime ");
	}
	if (TRUE == VarOptions.Bool_dossier_glade) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "glade ");
	}
	g_string_append_printf (VarBuild.GstrMakefileAm, "\nACLOCAL_AMFLAGS = -I m4\n");
	g_string_append_printf (VarBuild.GstrMakefileAm, "EXTRA_DIST = ");
	if (TRUE == VarOptions.Bool_dossier_po) {
		g_string_append_printf (VarBuild.GstrMakefileAm, "config.rpath m4/ChangeLog\n");
	}
}
// CONSTRUCTION configure.in
// 
void build_file_ConfigureIn (void)
{	
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrConfigureIn != NULL) {
		g_string_free (VarBuild.GstrConfigureIn, TRUE);
		VarBuild.GstrConfigureIn = NULL;
	}
	VarBuild.GstrConfigureIn = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrConfigureIn, "#\n# configure.in\n#\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "#                                               -*- Autoconf -*-\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "# Process this file with autoconf to produce a configure script.\n");
	
	g_string_append_printf (VarBuild.GstrConfigureIn, "\nAC_PREREQ(2.61)\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_INIT(%s, %d.%d.%d)\n",
					gtk_entry_get_text (GTK_ENTRY (VarCallbacks.Adr_name_project)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_version_A)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_version_B)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarCallbacks.Adr_spinbutton_version_C))
					);
	g_string_append_printf (VarBuild.GstrConfigureIn, "AM_INIT_AUTOMAKE\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_CONFIG_SRCDIR([src/main.c])\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_CONFIG_HEADER([config.h])\n");

	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Checks for programs.\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PROG_CXX\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PROG_CC\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PROG_CPP\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PROG_INSTALL\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "# AC_PROG_LN_S\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PROG_MAKE_SET\n");
	if (TRUE == VarOptions.Bool_dossier_lib_statique) {
		g_string_append_printf (VarBuild.GstrConfigureIn, "# AM_PROG_LIBTOOL\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PROG_RANLIB\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AM_PROG_CC_C_O\n");
		
		g_string_append_printf (VarBuild.GstrConfigureIn, "\nAC_DEFINE(ENABLE_STATIC_LIBRARY,1,[Define for enable static libarry])\n");
	}

	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Set PREFIX: ./configure  OR ./configure --prefix=/usr\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_SUBST(INSTALL_PREFIX)\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_PREFIX_DEFAULT(/usr/local)\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "if [[ $prefix = \"NONE\" ]] ; then\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_DEFINE(INSTALL_PREFIX, \"/usr/local\",\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "\t\t[define as prefix where %s is installed])\n", VarOptions.NameProject);
	g_string_append_printf (VarBuild.GstrConfigureIn, "else\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_DEFINE_UNQUOTED(INSTALL_PREFIX, \"$prefix\")\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "fi\n");
	
	if (TRUE == VarOptions.Bool_lib_gtk) {
		g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Set used name package glade: *.glade or *.ui\n");
		if (TRUE == VarOptions.Bool_package_name_is_glade) {
			g_string_append_printf (VarBuild.GstrConfigureIn,
					"AC_DEFINE(PACKAGE_NAME_GLADE, \"%s.glade\", [define as package name of glade])\n", VarOptions.NameProject);
		} else {
			g_string_append_printf (VarBuild.GstrConfigureIn,
					"AC_DEFINE(PACKAGE_NAME_GLADE, \"%s.ui\", [define as package name of ui])\n", VarOptions.NameProject);
		}
	}
	
	if (TRUE == VarOptions.Bool_dossier_po) {
		g_string_append_printf (VarBuild.GstrConfigureIn, "\n# nls support\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_MSG_CHECKING(for nls mode support)\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "XCFA_LANG=\"fr\"\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_ARG_ENABLE(nls, , [\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "if test \"$enableval\" = \"yes\"; then\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tALL_LINGUAS=$XCFA_LANG\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_MSG_RESULT(yes)\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAM_GNU_GETTEXT([external])\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_DEFINE(ENABLE_NLS,1,[Define for NLS support])\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "else\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_MSG_RESULT(no)\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tALL_LINGUAS=""\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tUSE_NLS=\"no\"\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "fi\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "], [\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tALL_LINGUAS=$XCFA_LANG\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_MSG_RESULT(yes)\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAM_GNU_GETTEXT([external])\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\tAC_DEFINE(ENABLE_NLS,1,[Define for NLS support])\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "])\n\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "GETTEXT_PACKAGE=[$PACKAGE]\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_SUBST(GETTEXT_PACKAGE)\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_DEFINE_UNQUOTED([GETTEXT_PACKAGE],[\"$GETTEXT_PACKAGE\"],[gettext domain])\n");
	}
	
	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Checks for libraries.\n");
	if (TRUE == VarOptions.Bool_dossier_lib_statique) {
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_CHECK_LIB([lib], [libH_print_mess])\n");
	}
	
	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Checks for header files.\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_HEADER_STDC\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_CHECK_HEADERS([libintl.h stdlib.h string.h unistd.h])\n");
	
	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Checks for typedefs, structures, and compiler characteristics.\n");

	g_string_append_printf (VarBuild.GstrConfigureIn, "\n# Checks for library functions.\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_FUNC_STAT\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "AC_CHECK_FUNCS([setlocale strchr strrchr])\n");
	
	{
		gchar	*Buf_debug =
	
		"\n#\n"
		"# debug and ansi support\n"
		"#\n"
		"AC_ARG_ENABLE(debug_pg, AC_HELP_STRING([--disable-debug-pg], [Enable debug mode (default=disable)]),,enable_debug_pg=no)\n"
		"AC_ARG_ENABLE(debug, AC_HELP_STRING([--disable-debug], [Disable debug mode (default=disable)]),,enable_debug=no)\n"
		"AC_ARG_ENABLE(ansi,  AC_HELP_STRING([--disable-ansi],  [Enable ansi (default=enabled)]),,enable_ansi=no)\n"
		"\n"
		"AC_MSG_CHECKING(for debug mode request)\n"
		"if test \"$enable_debug\" = \"yes\"; then\n"
		" 	AC_MSG_RESULT(yes)\n"
		"	AC_DEFINE(DEBUG,1,[Define for debug support])\n"
		"	AC_MSG_CHECKING(With ansi compilate)\n"
		"	if test \"$enable_ansi\" = \"yes\"; then\n"
		"		AC_MSG_RESULT(yes)\n"
		"		AC_DEFINE(ENABLE_ANSI,1,[Define With ansi compilate])\n"
		"		AC_MSG_CHECKING(With enable_debug_pg)\n"
		"		if test \"$enable_debug_pg\" = \"yes\"; then\n"
		"			AC_MSG_RESULT(yes)\n"
		"			AC_DEFINE(ENABLE_DEBUG_PG,1,[Define for debug gprof support])\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=yes, enable_ansi=yes, enable_debug_pg=yes\"\n"
		"			echo \"*** CFLAGS=-pg -g -O2 -Wall -ansi -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-pg -g -O2 -Wall -ansi -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		else\n"
		"			AC_MSG_RESULT(no)\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=yes, enable_ansi=yes, enable_debug_pg=no\"\n"
		"			echo \"*** CFLAGS=-g -O2 -Wall -ansi -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-g -O2 -Wall -ansi -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		fi\n"
		"	else\n"
		"		AC_MSG_RESULT(no)\n"
		"		AC_MSG_CHECKING(With enable_debug_pg)\n"
		"		if test \"$enable_debug_pg\" = \"yes\"; then\n"
		"			AC_MSG_RESULT(yes)\n"
		"			AC_DEFINE(ENABLE_DEBUG_PG,1,[Define for debug gprof support])\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=yes, enable_ansi=no, enable_debug_pg=yes\"\n"
		"			echo \"*** CFLAGS=-pg -g -O2 -Wall -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-pg -g -O2 -Wall -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		else\n"
		"			AC_MSG_RESULT(no)\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=yes, enable_ansi=no, enable_debug_pg=no\"\n"
		"			echo \"*** CFLAGS=-g -O2 -Wall -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-g -O2 -Wall -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		fi\n"
		"	fi\n"
		"else\n"
		" 	AC_MSG_RESULT(no)\n"
		"	AC_MSG_CHECKING(With ansi compilate)\n"
		" 	if test \"$enable_ansi\" = \"yes\"; then\n"
		" 		AC_MSG_RESULT(yes)\n"
		"		AC_DEFINE(ENABLE_ANSI,1,[Define With ansi compilate])\n"
		"		AC_MSG_CHECKING(With enable_debug_pg)\n"
		"		if test \"$enable_debug_pg\" = \"yes\"; then\n"
		"			AC_MSG_RESULT(yes)\n"
		"			AC_DEFINE(ENABLE_DEBUG_PG,1,[Define for debug gprof support])\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=no, enable_ansi=yes, enable_debug_pg=yes\"\n"
		"			echo \"*** CFLAGS=-pg -Wall -ansi -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-pg -Wall -ansi -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		else\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=no, enable_ansi=yes, enable_debug_pg=no\"\n"
		"			echo \"*** CFLAGS=-Wall -ansi -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-Wall -ansi -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		fi\n"
		"	else\n"
		"		AC_MSG_RESULT(no)\n"
		"		AC_MSG_CHECKING(With enable_debug_pg)\n"
		"		if test \"$enable_debug_pg\" = \"yes\"; then\n"
		"			AC_MSG_RESULT(yes)\n"
		"			AC_DEFINE(ENABLE_DEBUG_PG,1,[Define for debug gprof support])\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=no, enable_ansi=no, enable_debug_pg=yes\"\n"
		"			echo \"*** CFLAGS=-pg -Wall -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-pg -Wall -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		else\n"
		"			AC_MSG_RESULT(no)\n"
		"			echo \"***\"\n"
		"			echo \"*** enable_debug=no, enable_ansi=no, enable_debug_pg=no\"\n"
		"			echo \"*** CFLAGS=-Wall -D_REENTRANT -DLinux\"\n"
		"			echo \"***\"\n"
		"			CFLAGS=\"-Wall -O3 -D_REENTRANT -DLinux -Wl,--export-dynamic\"\n"
		"		fi\n"
		"	fi\n"
		"fi\n"
		"\n";
		
		g_string_append_printf (VarBuild.GstrConfigureIn, Buf_debug);
	}

	if (TRUE == VarOptions.Bool_lib_gtk || VarOptions.Bool_lib_gthread) {
		
		g_string_append_printf (VarBuild.GstrConfigureIn, "\n#\n# prerequis pour gtk\n#\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "pkg_modules=\"");
		if (TRUE == VarOptions.Bool_lib_gtk)
			g_string_append_printf (VarBuild.GstrConfigureIn, "gtk+-2.0 glib-2.0 ");
		if (TRUE == VarOptions.Bool_lib_gthread)
			g_string_append_printf (VarBuild.GstrConfigureIn, "gthread-2.0 ");
		g_string_append_printf (VarBuild.GstrConfigureIn, "\"\n");
		
		g_string_append_printf (VarBuild.GstrConfigureIn, "PKG_CHECK_MODULES(PACKAGE, [$pkg_modules])\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_SUBST(PACKAGE_CFLAGS)\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "AC_SUBST(PACKAGE_LIBS)\n");
		
		if (TRUE == VarOptions.Bool_lib_gthread) {
			g_string_append_printf (VarBuild.GstrConfigureIn, "\n#\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "# prerequis pour pthread\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "#\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "AC_CHECK_LIB([pthread], [pthread_create],,\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "[\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  echo \"***\"\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  echo \"*** Error! You need to have pthread around.\"\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  echo \"***\"\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  echo \"*** Install libc6\"\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  echo \"*** Install libc6-dev\"\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  echo \"***\"\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "  exit -1\n");
			g_string_append_printf (VarBuild.GstrConfigureIn, "])\n");
		}
	}
	
	g_string_append_printf (VarBuild.GstrConfigureIn, "\nAC_CONFIG_FILES([\n%s%sMakefile\nsrc/Makefile\n%s%s%s%s%s%s])\n",
						VarOptions.Bool_dossier_po ? "po/Makefile.in\n" : "",
						VarOptions.Bool_dossier_lib_statique ? "lib/Makefile\n" : "",
						VarOptions.Bool_dossier_src2 ? "src2/Makefile\n" : "",
						VarOptions.Bool_dossier_manpage ? "man/Makefile\n" : "",
						VarOptions.Bool_dossier_pixmaps ? "pixmaps/Makefile\n" : "",
						VarOptions.Bool_dossier_menu ? "menu/Makefile\n" : "",
						VarOptions.Bool_dossier_mime ? "mime/Makefile\n" : "",
						VarOptions.Bool_dossier_glade ? "glade/Makefile\n" : ""
						);

	g_string_append_printf (VarBuild.GstrConfigureIn, "\nAC_OUTPUT\n");

	g_string_append_printf (VarBuild.GstrConfigureIn, "\necho \"\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "Configuration for $PACKAGE $VERSION :\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "-----------------------------------\n\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  HosName ......................... : `hostname`\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Compiler ........................ : $CC $CPPFLAGS\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Linker .......................... : $CC $LDFLAGS\n");
	if (TRUE == VarOptions.Bool_lib_gtk || VarOptions.Bool_lib_gthread) {
		g_string_append_printf (VarBuild.GstrConfigureIn, " $LIBS\n");
	}
	if (TRUE == VarOptions.Bool_dossier_po) {
		g_string_append_printf (VarBuild.GstrConfigureIn, "  NLS/gettext ..................... : $USE_NLS\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "  ALL_LINGUAS ..................... : $ALL_LINGUAS\n");
	}
	if (TRUE == VarOptions.Bool_lib_gtk || VarOptions.Bool_lib_gthread) {
		g_string_append_printf (VarBuild.GstrConfigureIn, "  GTK+ version .................... : `pkg-config --modversion gtk+-2.0`\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "  GLIB version .................... : `pkg-config --modversion glib-2.0`\n");
		g_string_append_printf (VarBuild.GstrConfigureIn, "  GTHREAD version ................. : `pkg-config --modversion gthread-2.0`\n");
	}
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Debug mode g .................... : $enable_debug\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Debug mode pg ................... : $enable_debug_pg\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  WITH ANSI COMPILATE ............. : $enable_ansi\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  CFLAGS .......................... : $CFLAGS\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  INSTALL ......................... : $prefix/bin/%s\n\n", VarOptions.NameProject);
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Options parameters:\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  -------------------\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  by default:\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  	--disable-debug                             No debug support\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  	--disable-debug-pg                          No debug support with gprof\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  	--disable-ansi                              No define ansi for probleme compilate\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Options is:\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  	--enable-debug      #define DEBUG 1         Define for debug: -g\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  	--enable-debug-pg   #define DEBUG_PG 1      Define for debug support with gprof: -pg\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  	--enable-ansi       #define ENABLE_ANSI 1   Define With ansi compilate\n\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  Now type 'make' to build $PACKAGE $VERSION,\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "  and then type (under root) 'make install' for installation.\n");
	g_string_append_printf (VarBuild.GstrConfigureIn, "\"\n");
}
// CONSTRUCTION src/Makefile.am
// 
void build_file_SrcMakefileAm (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrSrcMakefileAm != NULL) {
		g_string_free (VarBuild.GstrSrcMakefileAm, TRUE);
		VarBuild.GstrSrcMakefileAm = NULL;
	}
	VarBuild.GstrSrcMakefileAm = g_string_new (NULL);
		
	g_string_append_printf (VarBuild.GstrSrcMakefileAm, "#\n# src/Makefile.am\n#\n");
	g_string_append_printf (VarBuild.GstrSrcMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	if (TRUE == VarOptions.Bool_lib_gtk) {
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "\nINCLUDES = \\\n");
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "   -DPACKAGE_DATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "   -DPACKAGE_LOCALE_DIR=\\\"\"$(prefix)/$(DATADIRNAME)/locale\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \\\n", VarOptions.NameProject);
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "	@PACKAGE_CFLAGS@\n");
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "\nAM_CFLAGS = @PACKAGE_CFLAGS@ \\\n");
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "   -DDATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "   -DLOCALE_DIR=\\\"\"$(datadir)/locale\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \n", VarOptions.NameProject);
	}
	g_string_append_printf (VarBuild.GstrSrcMakefileAm, "\nbin_PROGRAMS=%s\n", VarOptions.NameProject);
	g_string_append_printf (VarBuild.GstrSrcMakefileAm, "%s_SOURCES=main.c\n", VarOptions.NameProject);
	if (TRUE == VarOptions.Bool_dossier_lib_statique) {
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "\n%s_CPPFLAGS=-I${top_srcdir}/lib\n", VarOptions.NameProject);
	}
	if (TRUE == VarOptions.Bool_dossier_po) {
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "\ndatadir = @datadir@\n");
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "localedir = $(datadir)/locale\n");
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "DEFS = -DLOCALEDIR=\"$(localedir)\" @DEFS@\n");
	}
	if (TRUE == VarOptions.Bool_lib_gtk || TRUE == VarOptions.Bool_dossier_lib_statique || TRUE == VarOptions.Bool_dossier_po) {
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "\n%s_LDADD =", VarOptions.NameProject);
		if (TRUE == VarOptions.Bool_lib_gtk) {
			g_string_append_printf (VarBuild.GstrSrcMakefileAm, "@PACKAGE_LIBS@");
		}
		if (TRUE == VarOptions.Bool_dossier_po) {
			g_string_append_printf (VarBuild.GstrSrcMakefileAm, " $(INTLLIBS)");
		}
		if (TRUE == VarOptions.Bool_dossier_lib_statique) {
			g_string_append_printf (VarBuild.GstrSrcMakefileAm, " ${top_builddir}/lib/lib.a");
		}
		g_string_append_printf (VarBuild.GstrSrcMakefileAm, "\n");
	}
}
// CONSTRUCTION src2/Makefile.am
// 
void build_file_Src2MakefileAm (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrSrc2MakefileAm != NULL) {
		g_string_free (VarBuild.GstrSrc2MakefileAm, TRUE);
		VarBuild.GstrSrc2MakefileAm = NULL;
	}
	VarBuild.GstrSrc2MakefileAm = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "#\n# src2/Makefile.am\n#\n");
	g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	if (TRUE == VarOptions.Bool_lib_gtk) {
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "\nINCLUDES = \\\n");
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "   -DPACKAGE_DATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "   -DPACKAGE_LOCALE_DIR=\\\"\"$(prefix)/$(DATADIRNAME)/locale\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \\\n", VarOptions.NameProject);
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "	@PACKAGE_CFLAGS@\n");
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "\nAM_CFLAGS = @PACKAGE_CFLAGS@ \\\n");
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "   -DDATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "   -DLOCALE_DIR=\\\"\"$(datadir)/locale\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \n", VarOptions.NameProject);
	}
	g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "\nbin_PROGRAMS=%s1\n", VarOptions.NameProject);
	g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "%s1_SOURCES=main.c\n", VarOptions.NameProject);
	if (TRUE == VarOptions.Bool_dossier_lib_statique) {
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "\n%s1_CPPFLAGS=-I${top_srcdir}/lib\n", VarOptions.NameProject);
	}
	if (TRUE == VarOptions.Bool_dossier_po) {
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "\ndatadir = @datadir@\n");
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "localedir = $(datadir)/locale\n");
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "DEFS = -DLOCALEDIR=\"$(localedir)\" @DEFS@\n");
	}
	if (TRUE == VarOptions.Bool_lib_gtk || TRUE == VarOptions.Bool_dossier_lib_statique || TRUE == VarOptions.Bool_dossier_po) {
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "\n%s1_LDADD =", VarOptions.NameProject);
		if (TRUE == VarOptions.Bool_lib_gtk) {
			g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "@PACKAGE_LIBS@");
		}
		if (TRUE == VarOptions.Bool_dossier_po) {
			g_string_append_printf (VarBuild.GstrSrc2MakefileAm, " $(INTLLIBS)");
		}
		if (TRUE == VarOptions.Bool_dossier_lib_statique) {
			g_string_append_printf (VarBuild.GstrSrc2MakefileAm, " ${top_builddir}/lib/lib.a");
		}
		g_string_append_printf (VarBuild.GstrSrc2MakefileAm, "\n");
	}
}
// CONSTRUCTION man/Makefile.am
// 
void build_file_ManMakefileAm (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrManMakefileAm != NULL) {
		g_string_free (VarBuild.GstrManMakefileAm, TRUE);
		VarBuild.GstrManMakefileAm = NULL;
	}
	VarBuild.GstrManMakefileAm = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrManMakefileAm, "#\n# man/Makefile.am\n#\n");
	g_string_append_printf (VarBuild.GstrManMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	g_string_append_printf (VarBuild.GstrManMakefileAm, "man1_MANS = %s.1.gz\n", VarOptions.NameProject);
	g_string_append_printf (VarBuild.GstrManMakefileAm, "EXTRA_DIST = compilate_manpage.txt %s.1.gz\n", VarOptions.NameProject);
}
// CONSTRUCTION lib/Makefile.am
// 
void build_file_LibMakefileAm (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrLibMakefileAm != NULL) {
		g_string_free (VarBuild.GstrLibMakefileAm, TRUE);
		VarBuild.GstrLibMakefileAm = NULL;
	}
	VarBuild.GstrLibMakefileAm = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrLibMakefileAm, "#\n# lib/Makefile.am\n#\n");
	g_string_append_printf (VarBuild.GstrLibMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	if (TRUE == VarOptions.Bool_lib_gtk) {
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "\nINCLUDES = \\\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "   -DPACKAGE_DATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "   -DPACKAGE_LOCALE_DIR=\\\"\"$(prefix)/$(DATADIRNAME)/locale\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \\\n", VarOptions.NameProject);
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "	@PACKAGE_CFLAGS@\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "\nAM_CFLAGS = @PACKAGE_CFLAGS@ \\\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "   -DDATA_DIR=\\\"\"$(datadir)\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "   -DLOCALE_DIR=\\\"\"$(datadir)/locale\"\\\" \\\n");
		g_string_append_printf (VarBuild.GstrLibMakefileAm, "   -DPIXMAPS_DIR=\\\"\"$(datadir)/pixmaps/%s\"\\\" \n", VarOptions.NameProject);
	}
	g_string_append_printf (VarBuild.GstrLibMakefileAm, "noinst_LIBRARIES=lib.a\n");
	g_string_append_printf (VarBuild.GstrLibMakefileAm, "lib_a_SOURCES=lib.c lib.h\n");
}
// CONSTRUCTION pixmaps/Makefile.am
// 
void build_file_PixmapsMakefileAm (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrPixmapsMakefileAm != NULL) {
		g_string_free (VarBuild.GstrPixmapsMakefileAm, TRUE);
		VarBuild.GstrPixmapsMakefileAm = NULL;
	}
	VarBuild.GstrPixmapsMakefileAm = g_string_new (NULL);

	g_string_append_printf (VarBuild.GstrPixmapsMakefileAm, "#\n# pixmaps/Makefile.am\n#\n");
	g_string_append_printf (VarBuild.GstrPixmapsMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	g_string_append_printf (VarBuild.GstrPixmapsMakefileAm, "pixmaps_DATA = test%s.png\n", VarOptions.NameProject);
	g_string_append_printf (VarBuild.GstrPixmapsMakefileAm, "pixmapsdir = $(datadir)/pixmaps\n");
	g_string_append_printf (VarBuild.GstrPixmapsMakefileAm, "EXTRA_DIST = $(pixmaps_DATA)\n");
}
// CONSTRUCTION menu/Makefile.am
// 
void build_file_MenuMakefileAm (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrMenuMakefileAm != NULL) {
		g_string_free (VarBuild.GstrMenuMakefileAm, TRUE);
		VarBuild.GstrMenuMakefileAm = NULL;
	}
	VarBuild.GstrMenuMakefileAm = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrMenuMakefileAm, "#\n# menu/Makefile.am\n#\n");
	g_string_append_printf (VarBuild.GstrMenuMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	g_string_append_printf (VarBuild.GstrMenuMakefileAm, "menu_DATA = %s.desktop\n", VarOptions.NameProject);
	g_string_append_printf (VarBuild.GstrMenuMakefileAm, "menudir = $(datadir)/applications\n");
	g_string_append_printf (VarBuild.GstrMenuMakefileAm, "EXTRA_DIST = $(menu_DATA)\n");
	
}
// CONSTRUCTION mime/Makefile.am
// 
void build_file_MimeMakefileAm (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrMimeMakefileAm != NULL) {
		g_string_free (VarBuild.GstrMimeMakefileAm, TRUE);
		VarBuild.GstrMimeMakefileAm = NULL;
	}
	VarBuild.GstrMimeMakefileAm = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrMimeMakefileAm, "#\n# mime/Makefile.am\n#\n");
	g_string_append_printf (VarBuild.GstrMimeMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	g_string_append_printf (VarBuild.GstrMimeMakefileAm, "EXTRA_DIST = %s\n", VarOptions.NameProject);
	g_string_append_printf (VarBuild.GstrMimeMakefileAm, "mime_DATA = %s\n", VarOptions.NameProject);
	g_string_append_printf (VarBuild.GstrMimeMakefileAm, "mimedir = $(DESTDIR)/$(libdir)/mime/packages\n");
}
// CONSTRUCTION glade/Makefile.am
// 
void build_file_GladeMakefileAm (void)
{
	// REMOVE BUFFER IF EXIST
	if (VarBuild.GstrGladeMakefileAm != NULL) {
		g_string_free (VarBuild.GstrGladeMakefileAm, TRUE);
		VarBuild.GstrGladeMakefileAm = NULL;
	}
	VarBuild.GstrGladeMakefileAm = g_string_new (NULL);
	
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "#\n# glade/Makefile.am\n#\n");
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "AUTOMAKE_OPTIONS= gnu \n");
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "EXTRA_DIST = %s.ui %s.glade\n", VarOptions.NameProject, VarOptions.NameProject);
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "gladedir = $(datadir)/%s/glade\n", VarOptions.NameProject);
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "glade_DATA = %s.ui\n", VarOptions.NameProject);
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "\nuninstall:\n");
	g_string_append_printf (VarBuild.GstrGladeMakefileAm, "\trm -rf \"$(DESTDIR)$(datadir)/%s/\";\n", VarOptions.NameProject);
}
// CONSTRUCTION DES BUFFERS POUR LE TEXTVIEW
// 
void build_files (void)
{
	build_maj_options ();
	
	build_file_MakefileAm ();
	build_file_ConfigureIn ();
	build_file_SrcMakefileAm ();
	build_file_Src2MakefileAm ();
	build_file_ManMakefileAm ();
	build_file_LibMakefileAm ();
	build_file_PixmapsMakefileAm ();
	build_file_MenuMakefileAm ();
	build_file_MimeMakefileAm ();
	build_file_GladeMakefileAm ();

	// FREE ALLOCATIONS
	build_remove_options ();
}
// DESTRUCTION DES BUFFERS DU TEXTVIEW
// 
void build_remove (void)
{
	if (VarBuild.GstrMakefileAm != NULL) {
		g_string_free (VarBuild.GstrMakefileAm, TRUE);
		VarBuild.GstrMakefileAm = NULL;
	}
	if (VarBuild.GstrConfigureIn != NULL) {
		g_string_free (VarBuild.GstrConfigureIn, TRUE);
		VarBuild.GstrConfigureIn = NULL;
	}
	if (VarBuild.GstrSrcMakefileAm != NULL) {
		g_string_free (VarBuild.GstrSrcMakefileAm, TRUE);
		VarBuild.GstrSrcMakefileAm = NULL;
	}
	if (VarBuild.GstrManMakefileAm != NULL) {
		g_string_free (VarBuild.GstrManMakefileAm, TRUE);
		VarBuild.GstrManMakefileAm = NULL;
	}
	if (VarBuild.GstrLibMakefileAm != NULL) {
		g_string_free (VarBuild.GstrLibMakefileAm, TRUE);
		VarBuild.GstrLibMakefileAm = NULL;
	}
	if (VarBuild.GstrPixmapsMakefileAm != NULL) {
		g_string_free (VarBuild.GstrPixmapsMakefileAm, TRUE);
		VarBuild.GstrPixmapsMakefileAm = NULL;
	}
	if (VarBuild.GstrMenuMakefileAm != NULL) {
		g_string_free (VarBuild.GstrMenuMakefileAm, TRUE);
		VarBuild.GstrMenuMakefileAm = NULL;
	}
	if (VarBuild.GstrMimeMakefileAm != NULL) {
		g_string_free (VarBuild.GstrMimeMakefileAm, TRUE);
		VarBuild.GstrMimeMakefileAm = NULL;
	}
	if (VarBuild.GstrGladeMakefileAm != NULL) {
		g_string_free (VarBuild.GstrGladeMakefileAm, TRUE);
		VarBuild.GstrGladeMakefileAm = NULL;
	}
}

// --------------------------------------------------------------------------
// 
// GENERATION SUR MEMOIRE DE MASSE
// 
// --------------------------------------------------------------------------

// GENERATION 'Path + Name' avec le contenu de 'buffer'
// 
void build_create_file (gchar *Path, gchar *Name, gchar *Ext, gchar *buffer)
{
	gchar	*LineCommand = NULL;
	FILE	*fp = NULL;

	LineCommand = g_strdup_printf ("%s/%s%s", Path, Name, Ext);
	if (NULL != (fp = fopen (LineCommand, "w"))) {
		if (NULL != buffer)
			g_fprintf (fp, buffer);
		fclose (fp);
	}
	g_free (LineCommand);
	LineCommand = NULL;
}
// CREATION FICHIER lib/lib.c lib/lib.h
// 
void build_create_LIB_C_file (gchar *Path)
{
	gchar	*Buf_C =  "/*\n"
			" *  lib/lib.c\n"
			" */\n"
			"\n"
			"#include <stdio.h>\n"
			"\n"
			"void libH_print_mess (char *p_mess)\n"
			"{\n"
			"\tprintf(\"%%s\", p_mess);\n"
			"}\n"
			"\n";
	gchar	*Buf_H =  "/*\n"
			" *  lib/lib.h\n"
			" */\n"
			"\n"
			"#ifndef __libH_h__\n"
			"#define __libH_h__ 1\n"
			"\n"
			"void libH_print_mess (char *p_mess);\n"
			"\n"
			"#endif\n"
			"\n";
	
	// UNE FONCTION D AFFICHAGE DE TYPE GLOBALE: void libH_print_mess (char *p_mess);
	build_create_file (Path, "lib", ".c", Buf_C);
	build_create_file (Path, "lib", ".h", Buf_H);		
}
// CREATION FICHIER src/main.c
// 
void build_create_SRC_C_file (gchar *Path)
{	
	gchar *BufSrcWithoutGtk = 
		"/*\n"
		" *  src/main.c\n"
		" *  without GTK+-2.0\n"
		" */\n"
		"\n"
		"#ifdef HAVE_CONFIG_H\n"
		"	#include <config.h>\n"
		"#endif\n"
		"\n"
		"#ifdef ENABLE_NLS\n"
		"	#include <libintl.h>\n"
		"	#define _(String) gettext (String)\n"
		"#endif\n"
		"\n"
		"#include <stdio.h>\n"
		"#include <stdlib.h>\n"
		"\n"
		"#ifdef ENABLE_STATIC_LIBRARY\n"
		"	#include \"../lib/lib.h\"\n"
		"#endif\n"
		"\n"
		"/* int main (int argc, char *argv[], char **envp)\n"
		" *\n"
		" * argc  designe le nombre d'arguments transmis au moment du lancement de l'executable\n"
		" * argv  designe le vecteur contenant les differents arguments\n"
		" * envp  designe le vecteur contenant les informations sur l'environnement\n"
		" */\n"
		"int main (int argc, char *argv[], char **envp)\n"
		"{\n"
		"\tprintf (\"%%s :: %%s (line = %%d)\\n\", __FILE__, __FUNCTION__, __LINE__);"
		"\n"
		"#ifdef ENABLE_NLS\n"
		"\tprintf (_(\"Chaine a traduire depuis src/\\n\"));\n"
		"#endif\n"
		"\n"
		"#ifdef ENABLE_STATIC_LIBRARY\n"
		"\tlibH_print_mess (\"Appel fonction librairie statique depuis src = ok\\n\");\n"
		"#endif\n"
		"\texit(EXIT_SUCCESS);\n"
		"}\n"
		"\n";
	
	gchar BufSrcWithGtk [] = 
		"/*\n"
		" *  src/main.c\n"
		" *  with GTK+-2.0\n"
		" */\n"
		"\n"
		"#ifdef HAVE_CONFIG_H\n"
		"	#include <config.h>\n"
		"#endif\n"
		"\n"
		"#ifdef ENABLE_NLS\n"
		"	#include <libintl.h>\n"
		"	#define _(String) gettext (String)\n"
		"#endif\n"
		"\n"
		"#include <gtk/gtk.h>\n"
		"\n"
		"#include <stdio.h>\n"
		"#include <stdlib.h>\n"
		"\n"
		"#ifdef ENABLE_STATIC_LIBRARY\n"
		"	#include \"../lib/lib.h\"\n"
		"#endif\n"
		"\n"
		"\n"
		"GtkBuilder	*GtkBuilderProjet = NULL;\n"
		"GtkWidget	*WindMain = NULL;\n"
		"\n"
		"gboolean on_window_main_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)\n"
		"{\n"
		"#ifdef ENABLE_NLS\n"
		"	g_print(_(\"End of Program from delete_event\\n\"));\n"
		"#endif\n"
		"	gtk_main_quit ();\n"
		"	return FALSE;\n"
		"}\n"
		"gboolean on_window_main_destroy_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)\n"
		"{\n"
		"#ifdef ENABLE_NLS\n"
		"	g_print(_(\"End of Program from destroy_event\\n\"));\n"
		"#endif\n"
		"	gtk_main_quit ();\n"
		"	return FALSE;\n"
		"}\n"
		"void on_button_quit_clicked (GtkButton *button, gpointer user_data)\n"
		"{\n"
		"#ifdef ENABLE_NLS\n"
		"	g_print(_(\"End of Program from button\\n\\n\"));\n"
		"#endif\n"
		"	gtk_main_quit ();\n"
		"}\n"
		"\n"
		"/* gint main (gint argc, gchar *argv[], gchar **envp)\n"
		" *\n"
		" * argc  designe le nombre d'arguments transmis au moment du lancement de l'executable\n"
		" * argv  designe le vecteur contenant les differents arguments\n"
		" * envp  designe le vecteur contenant les informations sur l'environnement\n"
		" */\n"
		"gint main (gint argc, gchar *argv[], gchar **envp)\n"
		"{\n"
		"	GError	*p_err = NULL;\n"
		"	gchar	*CurrentDir = g_get_current_dir ();\n"
		"	gchar	*PathCurrentDir = NULL;\n"
		"	gchar	*PathShareProjet = NULL;\n"
		"	gchar	*Path = NULL;\n"
		"\n"
		"	g_print (\"%%s :: %%s (line = %%d)\\n\", __FILE__, __FUNCTION__, __LINE__);\n"
		"	g_print (\"\\n\");\n"
		"	g_print (\"***************************\\n\");\n"
		"	g_print (\"%%s %%s\\n\", PACKAGE, VERSION);\n"
		"	g_print (\"***************************\\n\");\n"
		"	g_print (\"%%s %%s compiled at %%s %%s\\n\", PACKAGE, VERSION, __DATE__, __TIME__);\n"
		"	g_print (\"Compiler: gcc %%s\\n\", __VERSION__);\n"
		"	g_print (\"***************************\\n\");\n"
		"	g_print (\"Gtk version  = %%d.%%d.%%d\\n\", GTK_MAJOR_VERSION, GTK_MICRO_VERSION, GTK_MINOR_VERSION);\n"
		"	g_print (\"Glib version = %%d.%%d.%%d\\n\", GLIB_MAJOR_VERSION, GLIB_MICRO_VERSION, GLIB_MINOR_VERSION);\n"
		"	g_print (\"***************************\\n\\n\");\n"
		"#ifdef ENABLE_NLS\n"
		"	g_print (\"ENABLE_NLS OK\\n\");\n"
		"	g_print (\"\\tGETTEXT_PACKAGE    = %%s\\n\", GETTEXT_PACKAGE);\n"
		"	g_print (\"\\tLOCALE_DIR         = %%s\\n\", LOCALE_DIR);\n"
		"\n"
		"	setlocale (LC_ALL, \"\");\n"
		"	bindtextdomain (GETTEXT_PACKAGE, LOCALE_DIR);\n"
		"	bind_textdomain_codeset (GETTEXT_PACKAGE, \"UTF-8\");\n"
		"	textdomain (GETTEXT_PACKAGE);\n"
		"#else\n"
		"	// g_error (\"ENABLE_NLS IS NOT OK\\n\\n\");\n"
		"#endif\n"
		"	gtk_set_locale ();\n"
		"	gtk_init (&argc, &argv);\n"
		"\n"
		"	if (NULL == (GtkBuilderProjet = gtk_builder_new ())) {\n"
		"		return (EXIT_FAILURE);\n"
		"	}\n"
		"	gtk_builder_set_translation_domain (GtkBuilderProjet, NULL);\n"
		"\n"
		"	PathCurrentDir = g_strdup_printf (\"%%s/glade/%%s\", CurrentDir, PACKAGE_NAME_GLADE);\n"
		"	g_free (CurrentDir);\n"
		"	CurrentDir = NULL;\n"
		"	PathShareProjet = g_strdup_printf (\"%%s/%%s/glade/%%s\", DATA_DIR, PACKAGE_NAME, PACKAGE_NAME_GLADE);\n"
		"\n"
		"	if (FALSE == g_file_test (PathCurrentDir, G_FILE_TEST_EXISTS) && FALSE == g_file_test (PathShareProjet, G_FILE_TEST_EXISTS)) {\n"
		"		g_print(\"!---------------------------------------------------------------------------------------------------\\n\");\n"
		"		g_print(\"! LE FICHIER XML: [ %%s ] N'EXISTE PAS !!!\\n\", PathCurrentDir);\n"
		"		g_print(\"!---------------------------------------------------------------------------------------------------\\n\");\n"
		"		g_print(\"! LE FICHIER XML: [ %%s ] N'EXISTE PAS !!!\\n\", PathShareProjet);\n"
		"		g_print(\"!---------------------------------------------------------------------------------------------------\\n\");\n"
		"\n"
		"		g_free (PathCurrentDir);\n"
		"		PathCurrentDir = NULL;\n"
		"		g_free (PathShareProjet);\n"
		"		PathShareProjet = NULL;\n"
		"\n"
		"		return (EXIT_FAILURE);\n"
		"	}\n"
		"	else if (TRUE == g_file_test (PathCurrentDir, G_FILE_TEST_EXISTS)) {\n"
		"\n"
		"		Path = PathCurrentDir;\n"
		"	}\n"
		"	else if (TRUE == g_file_test (PathShareProjet, G_FILE_TEST_EXISTS)) {\n"
		"\n"
		"		Path = PathShareProjet;\n"
		"	}\n"
		"	g_print(\"\\nPATHNAME FILE %%s: %%s\\n\\n\", PACKAGE_NAME_GLADE, Path);\n"
		"	if (gtk_builder_add_from_file (GtkBuilderProjet, Path, &p_err) <= 0) {\n"
		"		g_warning (\"Couldn't load builder file: %%s\", p_err->message);\n"
		"		g_error_free (p_err);\n"
		"\n"
		"		g_free (PathCurrentDir);\n"
		"		PathCurrentDir = NULL;\n"
		"		g_free (PathShareProjet);\n"
		"		PathShareProjet = NULL;\n"
		"		Path = NULL;\n"
		"\n"
		"		return (EXIT_FAILURE);\n"
		"	}\n"
		"	g_free (PathCurrentDir);\n"
		"	PathCurrentDir = NULL;\n"
		"	g_free (PathShareProjet);\n"
		"	PathShareProjet = NULL;\n"
		"	Path = NULL;\n"
		"\n"
		"	gtk_builder_set_translation_domain  (GtkBuilderProjet, gtk_set_locale ());\n"
		"	gtk_builder_connect_signals (GtkBuilderProjet, NULL);\n"
		"	WindMain = GTK_WIDGET (gtk_builder_get_object (GtkBuilderProjet, \"window_main\"));\n"
		"	gtk_widget_show (WindMain);\n"
		"	gtk_main ();\n"
		"\n"
		"	exit(EXIT_SUCCESS);\n"
		"}\n"
		"\n";

	if (TRUE == VarOptions.Bool_lib_gtk) {
		build_create_file (Path, "main", ".c", BufSrcWithGtk);
	}
	else {
		build_create_file (Path, "main", ".c", BufSrcWithoutGtk);
	}
}
// CREATION FICHIER src2/main.c
// 
void build_create_SRC2_C_file (gchar *Path)
{
	gchar *BufSrcWithoutGtk =
		"/*\n"
		" *  src/main.c\n"
		" *  without GTK+-2.0\n"
		" */\n"
		"\n"
		"#ifdef HAVE_CONFIG_H\n"
		"	#include <config.h>\n"
		"#endif\n"
		"\n"
		"#ifdef ENABLE_NLS\n"
		"	#include <libintl.h>\n"
		"	#define _(String) gettext (String)\n"
		"#endif\n"
		"\n"
		"#include <stdio.h>\n"
		"#include <stdlib.h>\n"
		"\n"
		"#ifdef ENABLE_STATIC_LIBRARY\n"
		"	#include \"../lib/lib.h\"\n"
		"#endif\n"
		"\n"
		"/* int main (int argc, char *argv[], char **envp)\n"
		" *\n"
		" * argc  designe le nombre d'arguments transmis au moment du lancement de l'executable\n"
		" * argv  designe le vecteur contenant les differents arguments\n"
		" * envp  designe le vecteur contenant les informations sur l'environnement\n"
		" */\n"
		"int main (int argc, char *argv[], char **envp)\n"
		"{\n"
		"\tprintf (\"%%s :: %%s (line = %%d)\\n\", __FILE__, __FUNCTION__, __LINE__);"
		"\n"
		"#ifdef ENABLE_NLS\n"
		"\tprintf (_(\"Chaine a traduire depuis src2/\\n\"));\n"
		"#endif\n"
		"\n"
		"#ifdef ENABLE_STATIC_LIBRARY\n"
		"\tlibH_print_mess (\"Appel fonction librairie statique depuis src2 = ok\\n\");\n"
		"#endif\n"
		"\texit(EXIT_SUCCESS);\n"
		"}\n"
		"\n";
	
	build_create_file (Path, "main", ".c", BufSrcWithoutGtk);
}
// CREATION FICHIER man/NOM_PROJET.1
// 
void build_create_MAN_file (void)
{
	GString	*Gstr = NULL;
	gchar	*NameManZip = NULL;
	gchar	*LineCommand = NULL;
 	gint	 RetSystem;
      
	// CONSTRUCTION DU FICHIER TEXTE MANPAGE
	Gstr = g_string_new (NULL);
	g_string_append_printf (Gstr, ".\\\" %s_man\n", VarOptions.NameProject);
	g_string_append_printf (Gstr, ".\\\" Copyright (C) 2010\n");
	g_string_append_printf (Gstr, ".\\\"\n");
	g_string_append_printf (Gstr, "\n");
	g_string_append_printf (Gstr, ".TH %s 1 \"Sat, 01 May 2010\" %s \"Page d'aide de: %s\"\n", VarOptions.NameProject, VarOptions.VersionProject, VarOptions.NameProject);
	g_string_append_printf (Gstr, "\n");
	g_string_append_printf (Gstr, ".SH NOM\n");
	g_string_append_printf (Gstr, "\\fB%s\\fP \\- GTK+ Implementation of the GNU.\n", VarOptions.NameProject);
	
	// ENREGISTREMENT DU FICHIER TEXTE MANPAGE
	NameManZip = g_strdup_printf ("%s.1", VarOptions.NameProject);
	build_create_file (VarOptions.PathNameMan, NameManZip, "", Gstr->str);
	g_string_free (Gstr, TRUE);
	Gstr = NULL;
	g_free (NameManZip);
	NameManZip = NULL;
	
	// CONSTRUCTION DU FICHIER ZIP MANPAGE
	NameManZip = g_strdup_printf ("%s/%s.1", VarOptions.PathNameMan, VarOptions.NameProject);
	LineCommand = g_strdup_printf ("gzip --best %s", NameManZip);
	RetSystem = system (LineCommand);
	g_free (LineCommand);
	LineCommand = NULL;
	g_free (NameManZip);
	NameManZip = NULL;
	
	// FICHIER D AIDE
	Gstr = g_string_new (NULL);
	g_string_append_printf (Gstr, "\n");
	g_string_append_printf (Gstr, "gzip --best ./%s.1\n\n", VarOptions.NameProject);
	build_create_file (VarOptions.PathNameMan, "compilate_manpage", ".txt", Gstr->str);
	g_string_free (Gstr, TRUE);
	Gstr = NULL;
}
// CREATION FICHIER man/NOM_PROJET.1.gz
// 
void build_create_MENU_file (void)
{
	GString	*Gstr = NULL;

	// CREATION FICHIER menu/NOM_PROJET.desktop
	Gstr = g_string_new (NULL);
	g_string_append_printf (Gstr, "[Desktop Entry]\n");
	g_string_append_printf (Gstr, "Version=%s\n", VarOptions.VersionProject);
	g_string_append_printf (Gstr, "Name=%s\n", VarOptions.NameProject);
	g_string_append_printf (Gstr, "Name[fr]=%s\n", VarOptions.NameProject);
	g_string_append_printf (Gstr, "GenericName[fr]=%s\n", VarOptions.NameProject);
	g_string_append_printf (Gstr, "Comment=%s. My new application with basebuild.\n", VarOptions.NameProject);
	g_string_append_printf (Gstr, "Icon=test%s.png\n", VarOptions.NameProject);
	g_string_append_printf (Gstr, "Type=Application\n");
	g_string_append_printf (Gstr, "Exec=%s\n", VarOptions.NameProject);
	g_string_append_printf (Gstr, "Terminal=false\n");
	g_string_append_printf (Gstr, "StartupNotify=true\n");
	g_string_append_printf (Gstr, "%s", Callbacks_get_entry_categories_item ());
	//	
	//	http://standards.freedesktop.org/menu-spec/1.0/apa.html
	//	AudioVideo
	//	Audio
	//	Video
	//	Development
	//	Education
	//	Game
	//	Graphics
	//	Network
	//	Office
	//	Settings
	//	System
	//	Utility
	
	build_create_file (VarOptions.PathNameMenu, VarOptions.NameProject, ".desktop", Gstr->str);
	g_string_free (Gstr, TRUE);
}
// CREATION FICHIERS glade/NOM_PROJET.glade + glade/NOM_PROJET.ui
// 
void build_create_GLADE_file (void)
{
	gchar *BufGlade = 
		"<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>\n"
		"<!DOCTYPE glade-interface SYSTEM \"glade-2.0.dtd\">\n"
		"<!--Generated with glade3 3.4.5 on Mon May  3 17:13:53 2010 -->\n"
		"<glade-interface>\n"
		"  <widget class=\"GtkWindow\" id=\"window_main\">\n"
		"    <property name=\"resizable\">False</property>\n"
		"    <property name=\"window_position\">GTK_WIN_POS_CENTER_ALWAYS</property>\n"
		"    <signal name=\"delete_event\" handler=\"on_window_main_delete_event\"/>\n"
		"    <signal name=\"destroy_event\" handler=\"on_window_main_destroy_event\"/>\n"
		"    <child>\n"
		"      <widget class=\"GtkVBox\" id=\"vbox1\">\n"
		"        <property name=\"visible\">True</property>\n"
		"        <property name=\"border_width\">5</property>\n"
		"        <child>\n"
		"          <widget class=\"GtkLabel\" id=\"label1\">\n"
		"            <property name=\"visible\">True</property>\n"
		"            <property name=\"label\">&lt;b&gt;BASE-BUILD&lt;/b&gt;&lt;i&gt;\n    with &lt;b&gt;GTK+-2.0    &lt;/b&gt;&lt;/i&gt;</property>\n"
		"            <property name=\"use_markup\">True</property>\n"
		"            <property name=\"justify\">GTK_JUSTIFY_CENTER</property>\n"
		"          </widget>\n"
		"        </child>\n"
		"        <child>\n"
		"          <widget class=\"GtkButton\" id=\"button_quit\">\n"
		"            <property name=\"visible\">True</property>\n"
		"            <property name=\"can_focus\">True</property>\n"
		"            <property name=\"receives_default\">True</property>\n"
		"            <property name=\"label\" translatable=\"yes\">gtk-quit</property>\n"
		"            <property name=\"use_stock\">True</property>\n"
		"            <property name=\"response_id\">0</property>\n"
		"            <signal name=\"clicked\" handler=\"on_button_quit_clicked\"/>\n"
		"          </widget>\n"
		"          <packing>\n"
		"            <property name=\"expand\">False</property>\n"
		"            <property name=\"position\">1</property>\n"
		"          </packing>\n"
		"        </child>\n"
		"      </widget>\n"
		"    </child>\n"
		"  </widget>\n"
		"</glade-interface>\n"
		"\n";
	gchar *BufUi = 
		"<?xml version=\"1.0\"?>\n"
		"<!--Generated with glade3 3.4.5 on Mon May  3 17:13:53 2010 -->\n"
		"<interface>\n"
		"  <object class=\"GtkWindow\" id=\"window_main\">\n"
		"    <property name=\"resizable\">False</property>\n"
		"    <property name=\"window_position\">GTK_WIN_POS_CENTER_ALWAYS</property>\n"
		"    <signal handler=\"on_window_main_delete_event\" name=\"delete_event\"/>\n"
		"    <signal handler=\"on_window_main_destroy_event\" name=\"destroy_event\"/>\n"
		"    <child>\n"
		"      <object class=\"GtkVBox\" id=\"vbox1\">\n"
		"        <property name=\"visible\">True</property>\n"
		"        <property name=\"border_width\">5</property>\n"
		"        <child>\n"
		"          <object class=\"GtkLabel\" id=\"label1\">\n"
		"            <property name=\"visible\">True</property>\n"
		"            <property name=\"label\">&lt;b&gt;BASE-BUILD&lt;/b&gt;&lt;i&gt;\n    with &lt;b&gt;GTK+-2.0    &lt;/b&gt;&lt;/i&gt;</property>\n"
		"            <property name=\"use_markup\">True</property>\n"
		"            <property name=\"justify\">GTK_JUSTIFY_CENTER</property>\n"
		"          </object>\n"
		"        </child>\n"
		"        <child>\n"
		"          <object class=\"GtkButton\" id=\"button_quit\">\n"
		"            <property name=\"visible\">True</property>\n"
		"            <property name=\"can_focus\">True</property>\n"
		"            <property name=\"receives_default\">True</property>\n"
		"            <property name=\"label\" translatable=\"yes\">gtk-quit</property>\n"
		"            <property name=\"use_stock\">True</property>\n"
		"            <signal handler=\"on_button_quit_clicked\" name=\"clicked\"/>\n"
		"          </object>\n"
		"          <packing>\n"
		"            <property name=\"expand\">False</property>\n"
		"            <property name=\"position\">1</property>\n"
		"          </packing>\n"
		"        </child>\n"
		"      </object>\n"
		"    </child>\n"
		"  </object>\n"
		"</interface>\n"
		"\n";

	build_create_file (VarOptions.PathNameGlade, VarOptions.NameProject, ".glade", BufGlade);
	build_create_file (VarOptions.PathNameGlade, VarOptions.NameProject, ".ui", BufUi);
}
// CREATION FICHIER po/fr.po
// 
void build_create_FR_PO_file (gchar *PathNamaneFileFR_PO)
{
	GString	*Gstr = NULL;
	FILE	*fp = NULL;
	
	Gstr = g_string_new (NULL);
	g_string_append_printf (Gstr, "# SOME DESCRIPTIVE TITLE.\n");
	g_string_append_printf (Gstr, "# Copyright (C) YEAR Free Software Foundation, Inc.\n");
	g_string_append_printf (Gstr, "# This file is distributed under the same license as the PACKAGE package.\n");
	g_string_append_printf (Gstr, "# FIRST AUTHOR <EMAIL@ADDRESS>, YEAR.\n");
	g_string_append_printf (Gstr, "#\n");
	// g_string_append_printf (Gstr, "#, fuzzy\n");
	g_string_append_printf (Gstr, "msgid \"\"\n");
	g_string_append_printf (Gstr, "msgstr \"\"\n");
	g_string_append_printf (Gstr, "\"Project-Id-Version: %s %s\\n\"\n", VarOptions.NameProject, VarOptions.VersionProject);
	g_string_append_printf (Gstr, "\"Report-Msgid-Bugs-To: Emailr@Adress.Ext\\n\"\n");
	g_string_append_printf (Gstr, "\"POT-Creation-Date: 2010-05-06 16:59+0200\\n\"\n");
	g_string_append_printf (Gstr, "\"PO-Revision-Date: 2010-05-06 16:59+0200\\n\"\n");
	g_string_append_printf (Gstr, "\"Last-Translator: MyName <Emailr@Adress.Ext>\\n\"\n");
	g_string_append_printf (Gstr, "\"Language-Team: French\\n\"\n");
	g_string_append_printf (Gstr, "\"MIME-Version: 1.0\\n\"\n");
	g_string_append_printf (Gstr, "\"Content-Type: text/plain; charset=UTF-8\\n\"\n");
	g_string_append_printf (Gstr, "\"Content-Transfer-Encoding: 8bit\\n\"\n");
	
	if (NULL != (fp = fopen (PathNamaneFileFR_PO, "w"))) {
		g_fprintf (fp, Gstr->str);
		fclose (fp);
	}
	g_string_free (Gstr, TRUE);
}
// COPIE FICHIERS /usr/share/pixmaps/$VarOptions.NameProject/testbasebuild.png
// 
gboolean build_create_PIXMAPS_file (void)
{
	gchar	*CurrentDir = g_get_current_dir ();
	gchar	*PathCurrentDir = NULL;
	gchar	*LineCommand = NULL;
	gint	 RetSystem;
	
	// TEST SOURCE FILE
	PathCurrentDir = g_strdup_printf ("%s/pixmaps/testbasebuild.png", CurrentDir);
	if (FALSE == libutils_test_file_exist (PathCurrentDir)) {
		g_free (PathCurrentDir);
		PathCurrentDir = NULL;
		PathCurrentDir = g_strdup_printf ("%s/pixmaps/testbasebuild.png", DATA_DIR);
		if (FALSE == libutils_test_file_exist (PathCurrentDir)) {
			g_free (PathCurrentDir);
			PathCurrentDir = NULL;
			return (FALSE);
		}
	}
	
	// SOURCE IN: PathCurrentDir
	// DEST IN:   VarOptions.PathNamePixmaps
	LineCommand = g_strdup_printf ("cp %s %s/test%s.png", PathCurrentDir, VarOptions.PathNamePixmaps, VarOptions.NameProject);
	RetSystem = system (LineCommand);
	g_free (LineCommand);
	LineCommand = NULL;
	g_free (CurrentDir);
	CurrentDir = NULL;
	
	return (TRUE);
}
// CREATION FICHIER mime/$VarOptions.NameProject
// 
void build_create_MIME_file (void)
{
	GString	*Gstr = NULL;
	
	Gstr = g_string_new (NULL);
	g_string_append_printf (Gstr, "application/ogg; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarOptions.NameProject, VarOptions.NameProject);
	g_string_append_printf (Gstr, "audio/basic; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarOptions.NameProject, VarOptions.NameProject);
	g_string_append_printf (Gstr, "audio/mpeg; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarOptions.NameProject, VarOptions.NameProject);
	g_string_append_printf (Gstr, "audio/x-aiff; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarOptions.NameProject, VarOptions.NameProject);
	g_string_append_printf (Gstr, "audio/x-mp3; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarOptions.NameProject, VarOptions.NameProject);
	g_string_append_printf (Gstr, "audio/x-wav; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarOptions.NameProject, VarOptions.NameProject);
	g_string_append_printf (Gstr, "application/x-flac; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarOptions.NameProject, VarOptions.NameProject);
	g_string_append_printf (Gstr, "audio/x-flac; %s '%%%%s'; edit=%s '%%%%s'; test=test \"$DISPLAY\" != \"\"; priority=2\n", VarOptions.NameProject, VarOptions.NameProject);
	build_create_file (VarOptions.PathNameMime, VarOptions.NameProject, "", Gstr->str);
	g_string_free (Gstr, TRUE);
}
// 
// 
void build_create_GETTEXTIZE_file (void)
{
	GString	*Gstr = NULL;
	gint	 RetSystem;
	
	Gstr = g_string_new (NULL);
	
	g_string_append_printf (Gstr, "#!/bin/sh\n");
	g_string_append_printf (Gstr, "PROGRAM=gettextize\n");
	g_string_append_printf (Gstr, "sed 's:read .*< /dev/tty::' `which $PROGRAM` > /tmp/my-gettextize.sh\n");
	g_string_append_printf (Gstr, "chmod +x /tmp/my-gettextize.sh\n");
	g_string_append_printf (Gstr, "exit 0\n");
	
	build_create_file ("/tmp", "set-gettextize.sh", "", Gstr->str);
	RetSystem = system ("chmod +x /tmp/set-gettextize.sh");
	RetSystem = system ("/tmp/set-gettextize.sh");
}
// GENERATION DU PROJET DEPUIS UN THREAD
// 
static void build_pthread_clicked (void *arg)
{
	gchar	*LineCommand = NULL;
	gchar	*TmpActuel = g_get_current_dir ();
	FILE	*fp = NULL;
	gchar	*PathNamePotfile = NULL;
	gint	 RetSystem = -2;
	
	PRINT_FUNC_LF();
	
	WindResult_set_text_va ("\nCREATION DU PROJET  [ ", VarOptions.NameProject, "-", VarOptions.VersionProject, " ]\n\n", NULL);
	
	// SUPPRESSION DU DOSSIER SI IL EXISTE
	if (g_file_test (VarOptions.NewPathName, G_FILE_TEST_IS_DIR)) {
		if (NULL != (LineCommand = g_strdup_printf ("rm -rf %s", VarOptions.NewPathName))) {
			WindResult_set_text_va ("SUPPRESSION DE L ANCIEN DOSSIER:\n\t", VarOptions.NewPathName, "\n", NULL);
			RetSystem = system (LineCommand);
			g_free (LineCommand);
			LineCommand = NULL;
		}
	}
	
	// CREATION DOSSIER DU PROJET
	WindResult_set_text_va ("CREATION DOSSIER DU PROJET:\n\t", VarOptions.NewPathName, "\n", NULL);
	g_mkdir_with_parents (VarOptions.NewPathName, 0700);
	
	// CREATION FICHIER Makefile.am
	WindResult_set_text_va ("\t", VarOptions.NewPathName, "/Makefile.am\n", NULL);
	build_create_file (VarOptions.NewPathName, "Makefile", ".am", VarBuild.GstrMakefileAm->str);

	// LES DOSSIERS LIBRAIRIE STATIQUE
	if (TRUE == VarOptions.Bool_dossier_lib_statique) {
		WindResult_set_text_va ("CREATION DOSSIER LIBRAIRIE STATIQUE:\n\t", VarOptions.PathNameLib, "\n", NULL);
		g_mkdir_with_parents (VarOptions.PathNameLib, 0700);
		// CREATION FICHIER Makefile.am
		WindResult_set_text_va ("\t", VarOptions.PathNameLib, "/Makefile.am\n", NULL);
		build_create_file (VarOptions.PathNameLib, "Makefile", ".am", VarBuild.GstrLibMakefileAm->str);
		// CREATION FICHIER lib/lib.c lib/lib.h
		WindResult_set_text_va ("\t", VarOptions.PathNameLib, "/lib.c\n", NULL);
		WindResult_set_text_va ("\t", VarOptions.PathNameLib, "/lib.h\n", NULL);
		build_create_LIB_C_file (VarOptions.PathNameLib);
	}
	
	// CREATE DOSSIER SRC	
	WindResult_set_text_va ("CREATION DOSSIER SOURCE:\n\t", VarOptions.PathNameSrc, "\n", NULL);
	g_mkdir_with_parents (VarOptions.PathNameSrc, 0700);
	
	// CREATION FICHIER Makefile.am
	WindResult_set_text_va ("\t", VarOptions.PathNameSrc, "/Makefile.am\n", NULL);
	build_create_file (VarOptions.PathNameSrc, "Makefile", ".am", VarBuild.GstrSrcMakefileAm->str);
	
	// CREATION FICHIER src/main.c
	WindResult_set_text_va ("\t", VarOptions.PathNameSrc, "/main.c\n", NULL);
	build_create_SRC_C_file (VarOptions.PathNameSrc);
	
	if (TRUE == VarOptions.Bool_dossier_src2) {
		WindResult_set_text_va ("CREATION DOSSIER SOURCE:\n\t", VarOptions.PathNameSrc2, "\n", NULL);
		g_mkdir_with_parents (VarOptions.PathNameSrc2, 0700);
		// CREATION FICHIER Makefile.am
		WindResult_set_text_va ("\t", VarOptions.PathNameSrc2, "/Makefile.am\n", NULL);
		build_create_file (VarOptions.PathNameSrc2, "Makefile", ".am", VarBuild.GstrSrc2MakefileAm->str);
		// CREATION FICHIER src2/main.c
		WindResult_set_text_va ("\t", VarOptions.PathNameSrc2, "/main.c\n", NULL);
		build_create_SRC2_C_file (VarOptions.PathNameSrc2);
	}
	if (TRUE == VarOptions.Bool_dossier_po) {
		WindResult_set_text_va ("CREATION DOSSIER INTERNATIONALISATION:\n\t", VarOptions.PathNamePo, "\n", NULL);
		g_mkdir_with_parents (VarOptions.PathNamePo, 0700);
	}
	if (TRUE == VarOptions.Bool_dossier_manpage) {
		WindResult_set_text_va ("CREATION DOSSIER MANPAGE:\n\t", VarOptions.PathNameMan, "\n", NULL);
		g_mkdir_with_parents (VarOptions.PathNameMan, 0700);
		// CREATION FICHIER Makefile.am
		WindResult_set_text_va ("\t", VarOptions.PathNameMan, "/Makefile.am\n", NULL);
		build_create_file (VarOptions.PathNameMan, "Makefile", ".am", VarBuild.GstrManMakefileAm->str);
		// CREATION FICHIER man.1.gz
		WindResult_set_text_va ("\t", VarOptions.PathNameMan, "/", VarOptions.NameProject, ".1.gz\n", NULL);
		build_create_MAN_file ();
	}
	if (TRUE == VarOptions.Bool_dossier_pixmaps) {
		WindResult_set_text_va ("CREATION DOSSIER PIXMAPS:\n\t", VarOptions.PathNamePixmaps, "\n", NULL);
		g_mkdir_with_parents (VarOptions.PathNamePixmaps, 0700);
		// CREATION FICHIER Makefile.am
		WindResult_set_text_va ("\t", VarOptions.PathNamePixmaps, "/Makefile.am\n", NULL);
		build_create_file (VarOptions.PathNamePixmaps, "Makefile", ".am", VarBuild.GstrPixmapsMakefileAm->str);
		// CREATION FICHIER pixmaps/testbasebuild.png
		WindResult_set_text_va ("\t", VarOptions.PathNamePixmaps, "/test", VarOptions.NameProject, ".png\n", NULL);
		build_create_PIXMAPS_file ();
	}
	if (TRUE == VarOptions.Bool_dossier_menu) {
		WindResult_set_text_va ("CREATION DOSSIER MENU:\n\t", VarOptions.PathNameMenu, "\n", NULL);
		g_mkdir_with_parents (VarOptions.PathNameMenu, 0700);
		// CREATION FICHIER Makefile.am
		WindResult_set_text_va ("\t", VarOptions.PathNameMenu, "/Makefile.am\n", NULL);
		build_create_file (VarOptions.PathNameMenu, "Makefile", ".am", VarBuild.GstrMenuMakefileAm->str);
		// CREATION FICHIER menu.menu
		WindResult_set_text_va ("\t", VarOptions.PathNameMenu, "/", VarOptions.NameProject, ".desktop\n", NULL);
		build_create_MENU_file ();
	}
	if (TRUE == VarOptions.Bool_dossier_mime) {
		WindResult_set_text_va ("CREATION DOSSIER MIME:\n\t", VarOptions.PathNameMime, "\n", NULL);
		g_mkdir_with_parents (VarOptions.PathNameMime, 0700);
		// CREATION FICHIER Makefile.am
		WindResult_set_text_va ("\t", VarOptions.PathNameMime, "/Makefile.am\n", NULL);
		build_create_file (VarOptions.PathNameMime, "Makefile", ".am", VarBuild.GstrMimeMakefileAm->str);
		// CREATION FICHIER mime.mime
		WindResult_set_text_va ("\t", VarOptions.PathNameMime, "/", VarOptions.NameProject, "\n", NULL);
		build_create_MIME_file ();
	}
	if (TRUE == VarOptions.Bool_dossier_glade) {
		WindResult_set_text_va ("CREATION DOSSIER GLADE:\n\t", VarOptions.PathNameGlade, "\n", NULL);
		g_mkdir_with_parents (VarOptions.PathNameGlade, 0700);
		// CREATION FICHIER Makefile.am
		WindResult_set_text_va ("\t", VarOptions.PathNameGlade, "/Makefile.am\n", NULL);
		build_create_file (VarOptions.PathNameGlade, "Makefile", ".am", VarBuild.GstrGladeMakefileAm->str);
		// CREATION FICHIER glade.glade glade.ui
		WindResult_set_text_va ("\t", VarOptions.PathNameGlade, "/", VarOptions.NameProject, ".glade\n", NULL);
		WindResult_set_text_va ("\t", VarOptions.PathNameGlade, "/", VarOptions.NameProject, ".ui\n", NULL);
		build_create_GLADE_file ();
	}
	
	// SE PLACER DANS LE DOSSIER VarOptions.NewPathName/
	g_chdir (VarOptions.NewPathName);
		
	// CREATION FICHIER configure.in
	WindResult_set_text_va ("CREATION FICHIER:\n\t", VarOptions.NewPathName, "/configure.in\n", NULL);
	build_create_file (VarOptions.NewPathName, "configure", ".in", VarBuild.GstrConfigureIn->str);
	
	if (TRUE == VarOptions.Bool_dossier_po) {
				
		// POUR OUTREPASSER GETTEXTIZE
		// http://culot.org/public/Docs/autotools.html
		WindResult_set_text_va ("OUTREPASSER\n\tgettextize AVEC /tmp/my-gettextize.sh\n", NULL);
		build_create_GETTEXTIZE_file ();
		
		// gettextize copie tous les fichiers standards Gettext dans le répertoire principal d'un package, pour commencer sa traduction.
		// Prise en compte de l'internationalisation qui modifie 'configure.in' et 'Makefile.am'
		// 	$ gettextize -c
		// Le fichier ./ABOUT-NLS sera cree
		WindResult_set_text_va ("EXEC\n\t/tmp/my-gettextize.sh -c\n", NULL);
		if (NULL != (LineCommand = g_strdup ("/tmp/my-gettextize.sh -c"))) {
			RetSystem = system (LineCommand);
			g_free (LineCommand);
			LineCommand = NULL;
		}
		
		WindResult_set_text_va ("SUPPRESSION DE:\n\t/tmp/set-gettextize.sh\n\t/tmp/my-gettextize.sh\n", NULL);
		g_unlink ("/tmp/set-gettextize.sh");
		g_unlink ("/tmp/my-gettextize.sh");
		
		// RENOMMER 'Makevars.template' vers 'po/Makevars'
		{
		gchar	*OldFile = g_strdup_printf ("%s/Makevars.template", VarOptions.PathNamePo);
		gchar	*NewFile = g_strdup_printf ("%s/Makevars", VarOptions.PathNamePo);
		WindResult_set_text_va ("RENOMMER:\n\t", OldFile, "\n\t", NewFile, "\n", NULL);
		g_rename(OldFile, NewFile);
		g_free (OldFile);
		OldFile = NULL;
		g_free (NewFile);
		NewFile = NULL;
		}
		
		// ADAPTATION DE 'po/POTFILES.in'
		PathNamePotfile = g_strdup_printf ("%s/POTFILES.in", VarOptions.PathNamePo);
		if (NULL != (fp = fopen (PathNamePotfile,"a"))) {
			WindResult_set_text_va ("AJOUTER A:\n\t", PathNamePotfile, "\n\t", "src/main.c\n", NULL);
			g_fprintf (fp, "src/main.c\n");
			if (TRUE == VarOptions.Bool_dossier_src2) {
				g_fprintf (fp, "src2/main.c\n");
				WindResult_set_text_va ("\t", "src2/main.c\n", NULL);
			}
			fclose (fp);
		}
		g_free (PathNamePotfile);
		PathNamePotfile = NULL;
		
		// RE CREATION FICHIER configure.in
		build_create_file (VarOptions.NewPathName, "configure", ".in", VarBuild.GstrConfigureIn->str);
		
		// RE CREATION FICHIER Makefile.am
		build_create_file (VarOptions.NewPathName, "Makefile", ".am", VarBuild.GstrMakefileAm->str);
				
		// CREATION po/fr.po
		PathNamePotfile = g_strdup_printf ("%s/fr.po", VarOptions.PathNamePo);
		WindResult_set_text_va ("CREATION FICHIER:\n\t", PathNamePotfile, "\n", NULL);
		build_create_FR_PO_file (PathNamePotfile);
		g_free (PathNamePotfile);
		PathNamePotfile = NULL;		
	}
	
	// CREATION FICHIERS ./NEWS ./README ./AUTHORS ./ChangeLog
	WindResult_set_text_va ("CREATION FICHIERS:\n\t",
					VarOptions.NewPathName, "/NEWS\n\t",
					VarOptions.NewPathName, "/README\n\t",
					VarOptions.NewPathName, "/AUTHORS\n\t",
					VarOptions.NewPathName, "/ChangeLog\n",
					NULL);
	build_create_file (VarOptions.NewPathName, "NEWS", "", NULL);
	build_create_file (VarOptions.NewPathName, "README", "", NULL);
	build_create_file (VarOptions.NewPathName, "AUTHORS", "", NULL);
	build_create_file (VarOptions.NewPathName, "ChangeLog", "", NULL);
		
	// CONSTRUCTION DU PAQUET
	WindResult_set_text_va ("EXEC\n\tautoscan\n", NULL);
	RetSystem = system ("autoscan");
	WindResult_set_text_va ("\taclocal\n", NULL);
	RetSystem = system ("aclocal");
	WindResult_set_text_va ("\tautoheader\n", NULL);
	RetSystem = system ("autoheader");
	WindResult_set_text_va ("\tautoconf\n", NULL);
	RetSystem = system ("autoconf");
	WindResult_set_text_va ("\tautomake -a -c\n", NULL);
	RetSystem = system ("automake -a -c");
	WindResult_set_text_va ("\tautomake --add-missing\n", NULL);
	RetSystem = system ("automake --add-missing");
	WindResult_set_text_va ("\tautomake\n", NULL);
	RetSystem = system ("automake");
	WindResult_set_text_va ("\t./configure --prefix=/usr\n", NULL);
	RetSystem = system ("./configure --prefix=/usr");
	WindResult_set_text_va ("\tmake\n", NULL);
	RetSystem = system ("make");
	WindResult_set_text_va ("\tmake distcheck\n", NULL);
	RetSystem = system ("make distcheck");
	
	// SE REPLACER DANS LE DOSSIER D ORIGINE
	g_chdir (TmpActuel);
	g_free (TmpActuel);
	TmpActuel = NULL;
	
	WindResult_set_text_va ("\n********************\nVOTRE PAQUET EST DISPONIBLE DEPUIS LE DOSSIER:\n\t", VarOptions.NewPathName, "/\n********************\n",  NULL);
	
	// FREE ALLOCATIONS
	build_remove_options ();
	
	// ACTIVER LE BOUTON QUITTER
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("button_quit_result")), TRUE);
	
	pthread_exit(0);
}
// APPEL A THREAD POUR LA GENERATION DU PROJET
// 
void build_clicked (void)
{
	pthread_t	 nmr_tid;
	GString		*Gstr = g_string_new (NULL);
	gboolean	 BoolErr = FALSE;
	
	build_maj_options ();
	
	// TEST PRESENCE DES PROGRAMMES EXTERNES
	if (FALSE == libutils_find_file ("gettextize") && TRUE == VarOptions.Bool_dossier_po) {
		g_string_append_printf (Gstr, "\t<b>gettextize</b>\n");
		BoolErr = TRUE;
	}
	if (FALSE == libutils_find_file ("autoscan")) {
		g_string_append_printf (Gstr, "\t<b>autoscan</b>\n");
		BoolErr = TRUE;
	}
	if (FALSE == libutils_find_file ("aclocal")) {
		g_string_append_printf (Gstr, "\t<b>aclocal</b>\n");
		BoolErr = TRUE;
	}
	if (FALSE == libutils_find_file ("autoheader")) {
		g_string_append_printf (Gstr, "\t<b>autoheader</b>\n");
		BoolErr = TRUE;
	}
	if (FALSE == libutils_find_file ("autoconf")) {
		g_string_append_printf (Gstr, "\t<b>autoconf</b>\n");
		BoolErr = TRUE;
	}
	if (FALSE == libutils_find_file ("automake")) {
		g_string_append_printf (Gstr, "\t<b>automake</b>\n");
		BoolErr = TRUE;
	}
	if (FALSE == libutils_find_file ("make")) {
		g_string_append_printf (Gstr, "\t<b>make</b>\n");
		BoolErr = TRUE;
	}
	if (TRUE == BoolErr) {
		build_remove_options ();
		wininfo_create (
			_("Applications absentes !"),
			_("   Applications a installer :            "),
			  "\n\n",
			  Gstr->str,
			  "\n",
			  "");
		
		g_string_free (Gstr, TRUE);
		return;
	}
	g_string_free (Gstr, TRUE);
	
	WinResult_open ();
	WindResult_clear_text ();
	// DESACTIVER LE BOUTON QUITTER
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("button_quit_result")), FALSE);
 	// THREAD
 	pthread_create (&nmr_tid, NULL ,(void *)build_pthread_clicked, (void *)NULL);
}













